# rules.tcl -- Help-browser (copied from "headache" (C) by Karl Garrison)

proc display_help {} {
    # Only display 1 help screen at once
    
    if {[winfo exists .help_screen]} {
        raise .help_screen
    }
    global help_text
    toplevel .help_screen
    frame .help_screen.top
    button .help_screen.dismiss -text "Dismiss" -command {destroy .help_screen}
    scrollbar .help_screen.top.yscroll -command {.help_screen.top.rules yview} \
     -orient vertical
    text .help_screen.top.rules  -width 65 -height 25 -padx 15 -pady 10 \
     -background white -wrap word -relief sunken -yscrollcommand \
     {.help_screen.top.yscroll set}
    wm title .help_screen "Rules"
    bind .help_screen <Escape> {destroy .help_screen}
    bind .help_screen <Return> {destroy .help_screen}
    bind .help_screen <Prior> {.help_screen.top.rules yview scroll -1 pages}
    bind .help_screen <Next> {.help_screen.top.rules yview scroll 1 pages}
    bind .help_screen <Up> {.help_screen.top.rules yview scroll -1 units}
    bind .help_screen <Down> {.help_screen.top.rules yview scroll 1 units}
    pack .help_screen.dismiss -side bottom -pady 10
    pack .help_screen.top -expand true -fill both -side bottom
    pack .help_screen.top.rules -side left -expand true -fill both
    pack .help_screen.top.yscroll -side left -fill y
    .help_screen.top.rules insert 1.0 $help_text
    .help_screen.top.rules configure -state disabled
    update idletasks
    focus .help_screen.dismiss
}

set help_text "
   Ishido is a tile-based game whose idea is taken from a Nint*ndo-g*meb*y game.

   I did not have anything but a g*meb*y and the Ishido game-cartridge, both borrowed for some time and given back already, so the rules implemented here may or may not be exactly the same as in the real game, but at least they look the same at the first glance ;-)


Rules:

   The goal of the game is to place all the 66 remaining tiles onto the board, on which 6 tiles are already pre-laid. The tiles each have 2 attributes: shape (square, rectangle, circle, triangle, cross and diamond) and fill (solid, stippled, empty, horiz.line, vert.line and center-dot). (If color-mode is selected, then the tiles show solid shapes in varying colors, rather than fill-patterns).  The six pre-laid tiles are not all randomly chosen, but rather are chosen such, that each shape and each fill(color) appears on exactly one of these tiles.

   You will be presented the next tile from a pouch. You can only put it to a certain place on the board, if:
 - The place is not already taken,
 - At least one of the four neighbouring places on the board is already taken,
 - None of the neighboring tiles are different in both attributes,
 - At least half of the neighbouring tiles must match each attribute.

For each shape-fill combination, exactly two tiles exist with that shape and fill. (That means, if for example two empty crosses are already placed on the board, then there is no use hoping for another empty cross to come.)


Examples:

You can place a solid circle to a certain place, if neighbouring that are ...
   Example 1:  only a solid square   or   only a horiz.line'd circle.
   Example 2:  a solid rectangle and a stippled circle.  
   Example 3:  a solid rectangle, a stippled circle and a center-dot'ted circle. (\"half of 3\" is considered \"one\", so one solid neighbour is enough)
   Example 4:  a solid cross, a solid triangle, a stippled circle and the other solid circle that exists. (three of them match fill, two of them match shape)

You can NOT place a solid circle to a certain place, if neighbouring that is/are ...
   Example *: any tile that has non-solid fill and non-circled shape.
   Example 0: nothing (that is the place is isolated).
   Example 1: only a center-dot'ted rectangle. (matches neither fill nor shape)
   Example 2: a solid cross and a solid rectangle. (none of these match the circle-attribute)
   Example 4: a solid cross, a stippled circle, a horiz.line'd circle and a vert.line'd circle. (only one of these has \"solid\", two are minimum for four neighbours)

Scoring:
   for tiles placed on the border (dark-shaded places), You won't get any points (although the matching-rules must still be satisfied). For tiles placed inside the amount of points gained depends on the number of neighbouring tiles:
 1 neighbouring tile: 1 point
 2 neighbouring tiles: 2 points
 3 neighbouring tiles: 4 points
 4 neighbouring tiles: This is also called a \"4Ways\"  and the number of points gained for a \"4Ways\" doubles each time, starting with 8 points. (First 4Ways: 8pts., 2nd 4Ways: 16pts., 3rd 4Ways: 32pts, ...)


Extra features:

   Buttons are almost all self-explanatory.
    game Id: this pops up a dialog that lets you view and control the random number engine. This is useful if you want to play against others: same random-seed (\"game Id\") --> same Game. (only integral values between about -2 billions and 2 billions)
   Checkbuttons: 
    Sound: if checked, will cause a beep (or system-sound), if you attempt to place a tile to an invalid place.
    Bubble: if checked, then the picture of the current tile will walk along with the current place on board. (otherwise, you will still see it in the bottom-right corner of the board)
    Pouch: if checked, display all tiles in the order that they will be (have been) served to you. The current tile is displayed sunken. (Note: examining the pouch is considered cheating)
    Color: if the whole game looks too pale to you, then check this. 
   Keyboard-shortcuts:
    q: quits game.
    g: shuffles pouch for new game.
    i: popup \"game Id\"-dialog.
    u(U): undoes one (all) steps.
    r(R): redoes one (all) steps.
    F1: display Rules. (what you're reading)
    Esc: let the floating tile disappear, until you move again.
    Enter,Space: place current tile onto selected place on board.
    Tab: cycle among board and the buttons to the right.
   Mouse-actions:
    Left button on board: place current tile onto selected place on board.
    Right button: same as \"u\" 
    Middle button: same as \"r\"


Comparing this game with the original:

 - The original also played music, and allowed multi-player-games.  All this is not implemented here.
 - This version allows unlimited \"Undo\"'s (and \"Redo\") (With the original only the last action could be undone)
 - Since this version is not constrained by the small display of a g*meb*y, you can keep the pouch visible all the time. (Note: This is considered cheating !)
 - The original also gives Bonus-points. I never managed to find out what they depend on, so they are not implemented here.
 - This game saves no high-scores. (The original forgot them anyway, each time power was turned off)
 - This version always tells you how many ways there are to place the current tile. The original only told you if there was no valid place for the current tile.



As you can probably tell from reading this, my first language is not English ;-)
Therefore let me know, if you think these rules are gibberish, (but also offer alternatives for paragraphs that sound too clumsy.)

(Copyright for the Tcl-implementation 1999 by Andreas Leitgeb)
(Copyright for the idea of the game by \"I should have written down the credits from the game's startup-screen\" :-)"

